# eric7.EricWidgets.EricProgressDialog

Module implementing a progress dialog allowing a customized progress bar label.

### Global Attributes

None

### Classes

EricProgressDialog | Class implementing a progress dialog allowing a customized progress bar label.

### Functions

None

## EricProgressDialog

Class implementing a progress dialog allowing a customized progress bar label.

### Derived from

QProgressDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricProgressDialog | Constructor
format | Public method to get the progress bar format.
setFormat | Public method to set the progress bar format.

### Static Methods

None

#### EricProgressDialog (Constructor)

EricProgressDialog(labelText, cancelButtonText, minimum, maximum, labelFormat=None, parent=None, flags=None, )

Constructor

labelText (str)
  text of the dialog label
cancelButtonText (str)
  text of the cancel button
minimum (int)
  minimum value
maximum (int)
  maximum value
labelFormat (str)
  label format of the progress bar
parent (QWidget)
  reference to the parent widget
flags (Qt.WindowFlags)
  window flags of the dialog

#### EricProgressDialog.format

format()

Public method to get the progress bar format.

Return:
  progress bar format

Return Type:
  str

#### EricProgressDialog.setFormat

setFormat(labelFormat)

Public method to set the progress bar format.

labelFormat (str)
  progress bar format

Up